from distutils.core import setup

setup(
    name = 'fish520',
    version = '1.1.0',
    py_modules = ['fish520'],
    author = 'fish520',
    author_email = '512735299@qq.com',
    url = 'http://www.shaniu520.com',
    description = 'a simple printer of fish lists',
    )
